from typing import List


def str_to_list(cmd_str: str) -> List[str]:
    return list(cmd_str.split())
